@@ -1574,20 +1574,21 @@ static ZIPARCHIVE_METHOD(open)
 		ze_obj->filename = NULL;
 	}
 
-#if LIBZIP_VERSION_MAJOR > 1 || LIBZIP_VERSION_MAJOR == 1 && LIBZIP_VERSION_MINOR >= 6
-	/* reduce BC break introduced in libzip 1.6.0
-	   "Do not accept empty files as valid zip archives any longer" */
-
 	/* open for write without option to empty the archive */
+#ifdef ZIP_RDONLY
 	if ((flags & (ZIP_TRUNCATE | ZIP_RDONLY)) == 0) {
+#else
+	if ((flags & ZIP_TRUNCATE) == 0) {
+#endif
 		zend_stat_t st;
 
 		/* exists and is empty */
 		if (VCWD_STAT(resolved_path, &st) == 0 && st.st_size == 0) {
+			/* reduce BC break introduced in libzip 1.6.0
+			   "Do not accept empty files as valid zip archives any longer" */
 			flags |= ZIP_TRUNCATE;
 		}
 	}
-#endif
 
 	intern = zip_open(resolved_path, flags, &err);
 	if (!intern || err) {
@@ -2826,7 +2827,6 @@ static ZIPARCHIVE_METHOD(extractTo)
 
 	zval *self = ZEND_THIS;
 	zval *zval_files = NULL;
-	zval *zval_file = NULL;
 	php_stream_statbuf ssb;
 	char *pathto;
 	size_t pathto_len;
@@ -2863,7 +2863,8 @@ static ZIPARCHIVE_METHOD(extractTo)
 					RETURN_FALSE;
 				}
 				for (i = 0; i < nelems; i++) {
-					if ((zval_file = zend_hash_index_find(Z_ARRVAL_P(zval_files), i)) != NULL) {
+					zval *zval_file;
+					if ((zval_file = zend_hash_index_find_deref(Z_ARRVAL_P(zval_files), i)) != NULL) {
 						switch (Z_TYPE_P(zval_file)) {
 							case IS_LONG:
 								break;
@@ -3637,16 +3638,25 @@ static PHP_MINFO_FUNCTION(zip)
 	php_info_print_table_row(2, "Zip", "enabled");
 	php_info_print_table_row(2, "Zip version", PHP_ZIP_VERSION);
 #ifdef HAVE_LIBZIP_VERSION
-	php_info_print_table_row(2, "Libzip headers version", LIBZIP_VERSION);
-	php_info_print_table_row(2, "Libzip library version", zip_libzip_version());
-#else
-	php_info_print_table_row(2, "Libzip version", LIBZIP_VERSION);
+	if (strcmp(LIBZIP_VERSION, zip_libzip_version())) {
+		php_info_print_table_row(2, "Libzip headers version", LIBZIP_VERSION);
+		php_info_print_table_row(2, "Libzip library version", zip_libzip_version());
+	} else
 #endif
+	{
+		php_info_print_table_row(2, "Libzip version", LIBZIP_VERSION);
+	}
 #ifdef HAVE_METHOD_SUPPORTED
 	php_info_print_table_row(2, "BZIP2 compression",
 		zip_compression_method_supported(ZIP_CM_BZIP2, 1) ? "Yes" : "No");
 	php_info_print_table_row(2, "XZ compression",
 		zip_compression_method_supported(ZIP_CM_XZ, 1) ? "Yes" : "No");
+#ifdef ZIP_CM_ZSTD
+	php_info_print_table_row(2, "ZSTD compression",
+		zip_compression_method_supported(ZIP_CM_ZSTD, 1) ? "Yes" : "No");
+#else
+	php_info_print_table_row(2, "ZSTD compression", "No");
+#endif
 	php_info_print_table_row(2, "AES-128 encryption",
 		zip_encryption_method_supported(ZIP_EM_AES_128, 1) ? "Yes" : "No");
 	php_info_print_table_row(2, "AES-192 encryption",
